@@ -14,7 +14,9 @@ class WialonBase:
 
         self._session = session
         self._id = str(id if id else self.create(*args, **kwargs))
-        self.populate()
+        self._name = None
+        self._hw_type = None
+        self._access_lvl = None
 
     def __str__(self) -> str:
         return str(self.id)
@@ -22,13 +24,34 @@ class WialonBase:
     def populate(self) -> None:
         """Retrieves and saves the latest data for the item from Wialon."""
         response = self.session.wialon_api.core_search_item(
-            **{"id": str(self.id), "flags": 0x1}
+            **{"id": str(self.id), "flags": flags.DataFlag.UNIT_BASE.value}
         )
         if response is not None:
             item = response.get("item", {})
-            self.name = item.get("nm")
-            self.hw_type = item.get("cls")
-            self.access_lvl = item.get("uacl")
+            self._name = item.get("nm")
+            self._hw_type = item.get("cls")
+            self._access_lvl = item.get("uacl")
+
+    @property
+    def name(self) -> str:
+        """Name of the Wialon object."""
+        if self._name is None:
+            self.populate()
+        return str(self._name)
+
+    @property
+    def hw_type(self) -> str:
+        """Hardware type of the Wialon object."""
+        if self._hw_type is None:
+            self.populate()
+        return str(self._hw_type)
+
+    @property
+    def access_lvl(self) -> str:
+        """Access level of the Wialon object."""
+        if self._access_lvl is None:
+            self.populate()
+        return str(self._access_lvl)
 
     @property
     def session(self) -> WialonSession:
@@ -205,7 +228,7 @@ class WialonBase:
     def cfields(self) -> dict[str, str]:
         """Custom fields for the Wialon object."""
         response = self.session.wialon_api.core_search_item(
-            **{"id": self.id, "flags": flags.DATAFLAG_UNIT_CUSTOM_FIELDS}
+            **{"id": self.id, "flags": flags.DataFlag.UNIT_CUSTOM_FIELDS.value}
         )
         fields = response.get("item", {}).get("flds") if response is not None else {}
         return {field["n"]: field["v"] for field in fields.values()} if fields else {}
@@ -214,7 +237,7 @@ class WialonBase:
     def afields(self) -> dict[str, str]:
         """Admin fields for the Wialon object."""
         response = self.session.wialon_api.core_search_item(
-            **{"id": self.id, "flags": flags.DATAFLAG_UNIT_ADMIN_FIELDS}
+            **{"id": self.id, "flags": flags.DataFlag.UNIT_ADMIN_FIELDS.value}
         )
         fields = response.get("item", {}).get("aflds") if response is not None else {}
         return {field["n"]: field["v"] for field in fields.values()} if fields else {}
